package org.objectweb.fractal.bf.connectors.upnp;

import java.io.IOException;

import org.cybergarage.upnp.device.InvalidDescriptionException;
import org.objectweb.fractal.bf.connectors.upnp.param.ParamSkeletonContent;
import org.ow2.binjiu.description.exception.UnpleasantTypeException;
import org.ow2.binjiu.description.java2upnp.J2UProcessor;
import org.ow2.binjiu.description.model2upnp.UPnPDeviceDescription;
import org.ow2.binjiu.runtime.device.APIDevice;
import org.ow2.binjiu.runtime.device.GenericCyberlinkDeviceWrapper;

public class UPnPSkeletonContent extends ParamSkeletonContent implements UPnPSkeletonContentAttributes {

	private GenericCyberlinkDeviceWrapper device;
	
	/**
	 * @throws  
	 * @see org.objectweb.fractal.api.control.LifeCycleController#startFc()
	 */
	@Override
	public void startFc() {
		log.fine("UPnP skeleton will be started...");

		try {
			String type = getType();
			
			if (type.equals(UPnPConnectorConstants.NO_TYPE))
				type = getServiceClass().getSimpleName() + UPnPConnectorConstants.TYPE_SUFFIX;
			
			// Create description
			UPnPDeviceDescription description = J2UProcessor.process(getServiceClass(), type, System.getProperty("java.io.tmpdir") );
							
			// Create UPnP device 
			this.device = APIDevice.createDevice(description.getComponent(), getServiceClass(), getServant(), description.getDeviceDescriptionFile());
			
			this.device.start();			
						
		} catch (UnpleasantTypeException e){
			log.severe(e.getMessage());
		} catch (InvalidDescriptionException e) {
			log.severe(e.getMessage());
		} catch (IOException e) {
			log.severe(e.getMessage());
		}
		
		super.startFc();
	}

	/**
	 * @see org.objectweb.fractal.api.control.LifeCycleController#stopFc()
	 */
	@Override
	public void stopFc() {
		log.fine("UPnP skeleton will be stopped...");
		if ( device!=null ) this.device.stop();
        super.stopFc();
	}

}
