/**
 * Fractal Binding Factory.
 * Copyright (C) 2010 INRIA, ADAM

 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contact: remi.melisson@inria.fr
 * 
 * Author: Rémi Mélisson
 * 
 */
package org.objectweb.fractal.bf.connectors.upnp.param;

import org.objectweb.fractal.bf.ExportHints;

/**
 * UPnP parameters hints to export a Fractal interface.
 * These hints model the attributes to configure the skeletons.
 *
 * @author Rémi Mélisson
 */
public class ParamExportHints implements ExportHints {
	/**
	 * The simple type of the device.
	 */
	private String type;

	/**
	 * Get the simple type of the device.
	 * 
	 * @return the simple type of the device.
	 */
	public String getType() {
		return type;
	}

	/**
	 * Set the simple type of the device.
	 * 
	 * @param type the simple type of the device.
	 */
	public void setType(String type) {
		this.type = type;
	}

	@Override
	public String toString() {
		StringBuffer sb = new StringBuffer("[");
		sb.append(ParamConnectorConstants.TYPE + ":");
		if (type != null) {
			sb.append(type);
		} else {
			sb.append("NOT-SET");
		}
		sb.append("]");
		return sb.toString();
	}
}
